==> com.liferay.data.engine.service-2.0.38-sources-commercial.jar: com/liferay/data/engine/internal/expando/util/DataEngineExpandoBridgeFactoryImpl.java <==
/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.data.engine.internal.expando.util;

import com.liferay.data.engine.internal.configuration.DataEngineConfiguration;
import com.liferay.data.engine.internal.expando.model.DataEngineExpandoBridgeImpl;
import com.liferay.data.engine.nativeobject.DataEngineNativeObject;
import com.liferay.data.engine.nativeobject.tracker.DataEngineNativeObjectTracker;
import com.liferay.data.engine.rest.resource.v2_0.DataDefinitionResource;
import com.liferay.data.engine.rest.resource.v2_0.DataRecordResource;
import com.liferay.expando.kernel.model.ExpandoBridge;
import com.liferay.expando.kernel.util.ExpandoBridgeFactory;
import com.liferay.portal.configuration.metatype.bnd.util.ConfigurableUtil;
import com.liferay.portal.kernel.service.GroupLocalService;
import com.liferay.portal.kernel.util.ArrayUtil;
import com.liferay.portlet.expando.model.impl.ExpandoBridgeImpl;

import java.util.Map;

import org.osgi.service.component.annotations.Activate;
import org.osgi.service.component.annotations.Component;
import org.osgi.service.component.annotations.Modified;
import org.osgi.service.component.annotations.Reference;
import org.osgi.service.component.annotations.ReferenceCardinality;
import org.osgi.service.component.annotations.ReferencePolicy;
import org.osgi.service.component.annotations.ReferencePolicyOption;

/**
 * @author Jeyvison Nascimento
 */
@Component(
	configurationPid = "com.liferay.data.engine.internal.configuration.DataEngineConfiguration",
	immediate = true, service = ExpandoBridgeFactory.class
)
public class DataEngineExpandoBridgeFactoryImpl
	implements ExpandoBridgeFactory {

	@Override
	public ExpandoBridge getExpandoBridge(long companyId, String className) {
		DataEngineNativeObject dataEngineNativeObject =
			_dataEngineNativeObjectTracker.getDataEngineNativeObject(className);

		if ((dataEngineNativeObject != null) &&
			ArrayUtil.contains(
				_dataEngineConfiguration.dataEngineNativeObjectClassNames(),
				dataEngineNativeObject.getClassName())) {

			try {
				return new DataEngineExpandoBridgeImpl(
					className, 0, companyId, _dataDefinitionResourceFactory,
					_dataRecordResourceFactory, _groupLocalService);
			}
			catch (Exception exception) {
				throw new RuntimeException(exception);
			}
		}

		return new ExpandoBridgeImpl(companyId, className);
	}

	@Override
	public ExpandoBridge getExpandoBridge(
		long companyId, String className, long classPK) {

		DataEngineNativeObject dataEngineNativeObject =
			_dataEngineNativeObjectTracker.getDataEngineNativeObject(className);

		if ((dataEngineNativeObject != null) &&
			ArrayUtil.contains(
				_dataEngineConfiguration.dataEngineNativeObjectClassNames(),
				dataEngineNativeObject.getClassName())) {

			try {
				return new DataEngineExpandoBridgeImpl(
					className, classPK, companyId,
					_dataDefinitionResourceFactory, _dataRecordResourceFactory,
					_groupLocalService);
			}
			catch (Exception exception) {
				throw new RuntimeException(exception);
			}
		}

		return new ExpandoBridgeImpl(companyId, className, classPK);
	}

	@Activate
	@Modified
	protected void activate(Map<String, Object> properties) {
		_dataEngineConfiguration = ConfigurableUtil.createConfigurable(
			DataEngineConfiguration.class, properties);
	}

	@Reference(
		cardinality = ReferenceCardinality.OPTIONAL,
		policy = ReferencePolicy.DYNAMIC,
		policyOption = ReferencePolicyOption.GREEDY
	)
	private volatile DataDefinitionResource.Factory
		_dataDefinitionResourceFactory;

	private volatile DataEngineConfiguration _dataEngineConfiguration;

	@Reference
	private DataEngineNativeObjectTracker _dataEngineNativeObjectTracker;

	@Reference(
		cardinality = ReferenceCardinality.OPTIONAL,
		policy = ReferencePolicy.DYNAMIC,
		policyOption = ReferencePolicyOption.GREEDY
	)
	private volatile DataRecordResource.Factory _dataRecordResourceFactory;

	@Reference
	private GroupLocalService _groupLocalService;

}

==> com.liferay.data.engine.service-3.0.36-sources-commercial.jar: com/liferay/data/engine/internal/expando/util/DataEngineExpandoBridgeFactoryImpl.java <==
/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.data.engine.internal.expando.util;

import com.liferay.data.engine.internal.configuration.DataEngineConfiguration;
import com.liferay.data.engine.internal.expando.model.DataEngineExpandoBridgeImpl;
import com.liferay.data.engine.nativeobject.DataEngineNativeObject;
import com.liferay.data.engine.nativeobject.tracker.DataEngineNativeObjectTracker;
import com.liferay.dynamic.data.mapping.form.field.type.DDMFormFieldTypeServicesTracker;
import com.liferay.expando.kernel.model.ExpandoBridge;
import com.liferay.expando.kernel.util.ExpandoBridgeFactory;
import com.liferay.portal.configuration.metatype.bnd.util.ConfigurableUtil;
import com.liferay.portal.kernel.service.GroupLocalService;
import com.liferay.portal.kernel.util.ArrayUtil;
import com.liferay.portlet.expando.model.impl.ExpandoBridgeImpl;

import java.util.Map;

import org.osgi.service.component.annotations.Activate;
import org.osgi.service.component.annotations.Component;
import org.osgi.service.component.annotations.Modified;
import org.osgi.service.component.annotations.Reference;

/**
 * @author Jeyvison Nascimento
 */
@Component(
	configurationPid = "com.liferay.data.engine.internal.configuration.DataEngineConfiguration",
	immediate = true, service = ExpandoBridgeFactory.class
)
public class DataEngineExpandoBridgeFactoryImpl
	implements ExpandoBridgeFactory {

	@Override
	public ExpandoBridge getExpandoBridge(long companyId, String className) {
		DataEngineNativeObject dataEngineNativeObject =
			_dataEngineNativeObjectTracker.getDataEngineNativeObject(className);

		if ((dataEngineNativeObject != null) &&
			ArrayUtil.contains(
				_dataEngineConfiguration.dataEngineNativeObjectClassNames(),
				dataEngineNativeObject.getClassName())) {

			try {
				return new DataEngineExpandoBridgeImpl(
					className, 0, companyId, _ddmFormFieldTypeServicesTracker,
					_groupLocalService);
			}
			catch (Exception exception) {
				throw new RuntimeException(exception);
			}
		}

		return new ExpandoBridgeImpl(companyId, className);
	}

	@Override
	public ExpandoBridge getExpandoBridge(
		long companyId, String className, long classPK) {

		DataEngineNativeObject dataEngineNativeObject =
			_dataEngineNativeObjectTracker.getDataEngineNativeObject(className);

		if ((dataEngineNativeObject != null) &&
			ArrayUtil.contains(
				_dataEngineConfiguration.dataEngineNativeObjectClassNames(),
				dataEngineNativeObject.getClassName())) {

			try {
				return new DataEngineExpandoBridgeImpl(
					className, classPK, companyId,
					_ddmFormFieldTypeServicesTracker, _groupLocalService);
			}
			catch (Exception exception) {
				throw new RuntimeException(exception);
			}
		}

		return new ExpandoBridgeImpl(companyId, className, classPK);
	}

	@Activate
	@Modified
	protected void activate(Map<String, Object> properties) {
		_dataEngineConfiguration = ConfigurableUtil.createConfigurable(
			DataEngineConfiguration.class, properties);
	}

	private volatile DataEngineConfiguration _dataEngineConfiguration;

	@Reference
	private DataEngineNativeObjectTracker _dataEngineNativeObjectTracker;

	@Reference
	private DDMFormFieldTypeServicesTracker _ddmFormFieldTypeServicesTracker;

	@Reference
	private GroupLocalService _groupLocalService;

}
